@@ -2,6 +2,10 @@ import typing
 
 
 def check_type(actual, definition):
+    if type(definition) == typing.TypeVar:
+        # Currently any type variable will be considered generic
+        return True
+
     if hasattr(definition, "__origin__") and definition.__origin__ == list:
         # The only valid case is that they're both lists, and
         # if that's the case we want to check their types
